Skip to contents

This function calculates the yearly index for a species by averaging monthly index values.

Usage

calc_truth_index_yearly(truth_index_monthly)

Arguments

truth_index_monthly

A tibble containing the monthly index data for a species. Returned from calc_truth_index_monthly().

Value

A tibble containing the yearly index (e.g., biomass and catch) for the specified species.

Examples

data(ewe_ecosim_base_nwatlantic)
data <- ewe_ecosim_base_nwatlantic
truth_index_yearly <- ecosystemom:::calc_truth_monthly(
  data,
  species_name = "menhaden",
  truth_type = "biomass"
) |>
  ecosystemom:::calc_truth_index_monthly() |>
  ecosystemom:::calc_truth_index_yearly()