Calculate "true" monthly index for a species
calc_truth_index_monthly.RdThis function calculates the monthly index for a species by summing the values across all ages by month.
Arguments
- truth_monthly
A tibble containing the monthly "truth" data for a species. Returned from
calc_truth_monthly().
Examples
data(ewe_ecosim_base_nwatlantic)
data <- ewe_ecosim_base_nwatlantic
truth_index_monthly <- ecosystemom:::calc_truth_monthly(
data,
species_name = "menhaden",
truth_type = "biomass"
) |>
ecosystemom:::calc_truth_index_monthly()